.. yamanifest documentation master file, created by
   sphinx-quickstart on Fri May 13 10:16:43 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to yamanifest's documentation!
======================================================

Contents:

.. toctree::
   :maxdepth: 2

   readme.rst 
   api/autoindex.rst
   api/modules.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

